@@ -9,14 +9,13 @@ from .handlers import (
     StartHandler,
     TextHandler,
 )
-from .keyboards import InlineButtons, InlineKeyboard
+from .keyboards import InlineKeyboard
 from .loader import app
 from .texts import Texts
 
 __all__ = [
     "app",
     "Texts",
-    "InlineButtons",
     "InlineKeyboard",
     "UrlButton",
     "CallbackButton",
