@@ -1,7 +1,9 @@
-from .reply import ReplyContext
+from botty_core import Callback
+
+from .update import UpdateContext
 
 
-class TextContext(ReplyContext):
+class TextContext(UpdateContext):
     @property
     def text(self) -> str:
         return self.message.text
@@ -9,3 +11,6 @@ class TextContext(ReplyContext):
     @property
     def text_words(self) -> list[str]:
         return self.text.lower().split()
+
+
+TextCallback = Callback[TextContext]
