@@ -1,4 +1,4 @@
-from botty_core.types import PTBContext
+from botty_core import PTBContext
 from telegram import Update, ext
 
 from botty.contexts import TextCallback, TextContext
