@@ -3,9 +3,9 @@ from typing import TypeVar
 
 import telegram
 
-from botty_core.types import Bot, Chat, Message, PTBContext, Update, User
+from botty_core.types import Bot, Chat, Message, Update, User
 
-T = TypeVar("T")
+from .ptb_types import PTBContext
 
 
 class Context:
@@ -30,20 +30,6 @@ class Context:
     def effective_user(self) -> User:
         return self.update.effective_user
 
-    def get_validated_field(self, name: str, value: T | None) -> T:
-        if value is None:
-            raise ContextFieldError(self, name)
-        return value
-
-
-class ContextFieldError(AttributeError):
-    def __init__(self, context: Context, field: str) -> None:
-        self.context = context
-        self.field = field
-
-    def __str__(self) -> str:
-        return f"No `{self.field}` for {self.context}"
-
 
 ContextT = TypeVar("ContextT", bound=Context)
 Callback = Callable[[ContextT], Awaitable[None]]
