@@ -13,17 +13,17 @@ class Query(TelegramObject):
 
     @property
     def data(self) -> str:
-        return self.get_validated_field("data", self.raw.data)
-
-    async def answer(self, text: str = "", *, show_alert: bool = False) -> bool:
-        return await self.raw.answer(text, show_alert)
+        return self.check_field("data", self.raw.data)
 
     @property
     def message(self) -> Message:
-        raw = self.get_validated_field("message", self.raw.message)
+        raw = self.check_field("message", self.raw.message)
         return Message(raw)
 
     @property
     def user(self) -> User:
-        raw = self.get_validated_field("user", self.raw.from_user)
+        raw = self.check_field("user", self.raw.from_user)
         return User(raw)
+
+    async def answer(self, text: str = "", *, show_alert: bool = False) -> bool:
+        return await self.raw.answer(text, show_alert)
